function h_over_R = fillingDegree2Height(f)

% Calculates the ratio of the filling height (h) of a cylindrical drum to
% the radius (R) of the drum, for a given volume filling degree (f).

% Theodoros-Nestor Papapetrou
% Last edited: 09 Oct 2020

%% Input

% f: volume filling degree of the drum, i.e. the fraction of the total
% volume of the drum filled with particles. The bulk volume of the particle
% bed is used (double scalar, between 0 and 1)

%% Output

% h_over_R: filling height (h) over drum radius (R). The filling height is
% considered as if all the particles were distributed inside the drum so
% that the free surface would form a perfect horizontal plane (double
% scalar, between 0 and 1)

%% Calculate filling angle, phi

tau = 2*pi;

% The filling degree is calculated as the ratio of the granular area of a
% cross-section of the drum, R^2*(phi - sin(phi))/2, to the total area of
% the cross-section, pi*R^2. After simplification, this ratio becomes:
% f = (phi - sin(phi))/tau
% The above equation is solved for phi.
Df = @(ph) (ph - sin(ph))/tau - f; % must equal zero
phi = fzero(Df, [0, tau]);

%% Calculate h_over_R

h_over_R = 1 - cos(phi/2);