function [l_over_D,redArea_over_totalArea] = redAreaVSmodifiedLength(f)

% Calculates the coordinates of the plot of the modified red granular area
% used for the calculation of the minimum contact length, normalized by the
% total drum area, as a function of the modified length, indicating the
% horizontal position of the vertical separating line, normalized by the
% drum diameter (Fig. 6 in the paper).

% Theodoros-Nestor Papapetrou
% Last edited: 09 Oct 2020

%% Input

% f: volume filling degree of the drum, i.e. the fraction of the total
% volume of the drum filled with particles. The bulk volume of the particle
% bed is used (double scalar, between 0 and 1). See the function
% fillingDegree2Height for more information

%% Output

% l_over_D: the x-axis values, the ratio of l (modified length, indicating
% the horizontal position of the vertical separating line) over D (drum
% diameter) (double scalar, between 0 and 1)

% redArea_over_totalArea: the y-axis values, the ratio of the modified red
% granular area (Eq. 15) over the total area of the drum cross-section
% (pi*D^2/4) (double scalar, between 0 and f)

%% Calculate the filling height, h

R = 1; % drum radius, basis for the calculations, does not affect the
% calculated ratios

D = 2*R; % drum diameter
h = fillingDegree2Height(f);

%% x values (l_over_D)

N = 500; % number of sampling positions
l = linspace(0,D,N);
l_over_D = l/D;

%% y values (redArea_over_totalArea)

red_area = zeros(1,N);
for ii = 1:N
    red_area(ii) = redArea(R,h,l(ii));
end

totalArea = pi*R^2;
redArea_over_totalArea = red_area/totalArea;
