function [Prow,Pcol,Chor,Cver,C] = shiftPixels(P)

% Shifts the background pixels of an image, independently in the horizontal
% and vertical directions (see e.g. Fig. 3), and counts the number of
% modified contacts independently in the two directions.
% A faster way to count the modified contacts is used in the function
% M_cont_modified.m
% which does not generate the two images with the shifted pixels.

% Theodoros-Nestor Papapetrou
% Last edited: 06 Oct 2020

%% Input

% P: uint8 H x W matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)
% P represents an image of the rotating drum with red and white particles

%% Output

% Prow: P with the 0 elements shifted to the right in each row
% Pcol: P with the 0 elements shifted down in each column
% Prow and Pcol are uint8 matrices and follow the same number-color
% correspondence as P

% Chor: number of horizontal modified contacts, counted from Prow (integer)
% Cver: number of vertical modified contacts, counted from Pcol (integer)
% C = Chor + Cver: total number of modified contacts (integer)

%% Initialization

[H,W] = size(P);

%% Prow and Chor: operations along each row

% Pixel shifting in the row direction
nzrows = arrayfun(@(ii) nonzeros(P(ii,:)), 1:H, 'uniformoutput', false);

% Counting contacts in each shifted row
Prow = zeros(H,max(cellfun(@length,nzrows)));
for ii = 1:H
    Prow(ii,1:length(nzrows{ii})) = nzrows{ii}';
end
Chor = find_noOfContacts(Prow,'row');

%% Pcol and Cver: operations along each column

% Pixel shifting in the column direction
nzcols = arrayfun(@(jj) nonzeros(P(:,jj)), 1:W, 'uniformoutput', false);

% Counting contacts in each shifted column
Pcol = zeros(max(cellfun(@length,nzcols)),W);
for jj = 1:W
    Pcol(1:length(nzcols{jj}),jj) = nzcols{jj};
end
Cver = find_noOfContacts(Pcol,'col');

%% Total number of contacts

C = Chor + Cver;